@@ -44,7 +44,7 @@ from google.cloud.functions.context import Context
 from functions_framework._of.v2.context import FunctionContext
 _FUNC_CTX = dict()
 KNATIVE_FUNC = "Knative"
-ASYNC = "Async"
+ASYNC = "async"
 
 MAX_CONTENT_LENGTH = 10 * 1024 * 1024
 
@@ -430,7 +430,7 @@ class LazyWSGIApp:
                 if _ctx.runtime == KNATIVE_FUNC:
                     print("start http app")
                     self.app = create_app(self.target, self.source, self.signature_type)
-                elif _ctx.runtime == ASYNC:
+                elif str(_ctx.runtime).lower() == ASYNC:
                     signature_type = "of"
                     print(datetime.now())
                     print("start dapr app")
